@@ -31,7 +31,7 @@ use Sim::OPT::Parcoord3d;
 
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
-$VERSION = '0.159';
+$VERSION = '0.161';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -2124,7 +2124,6 @@ Here below is an example of multivatiate dataseries of 3 parameters assuming 3 l
 3,3,3,3
 
 
-Note that the parameter listings cannot be incomplete. Just the objective function entries can be.
 The program converts this format into the one preferred by Sim::OPTS, which is the following:
 
 
@@ -2147,6 +2146,23 @@ The program converts this format into the one preferred by Sim::OPTS, which is t
 1-3_2-3_3-3
 
 
+(((Note that the parameter listings cannot be incomplete if Interlinear is to be involved without involving Sim::OPT. Just the objective function entries can be incomplete. The following series, for example, is a version of the series above, incomplete as regards the parameter listings:
+
+1-1_2-1_3-1,9.234
+
+1-1_2-2_3-2,4.500
+
+1-2_2-1_3-1,7.534
+
+1-2_2-2_3-2,0.000
+
+1-2_2-3_3-3,0.550
+
+1-3_2-2_3-2,0.670
+
+However, involving Sim::OPT is more complicated that utilizing Interlinear alone. How to do that is treated at the end of this document.)))
+
+
 After some computations, Interlinear will output a new dataseries with the missing values filled in.
 This dataseries can be used by OPT for the optimization of one or more blocks. This can be useful, for example, to save computations in searches involving simulations, especially when the time required by each simulations is long, like it may happen with CFD simulations in building design.
 
@@ -2173,6 +2189,27 @@ Or to begin with a dialogue question:
 ./Interlinear.pm interstart;
 .
 
+######################
+
+
+How to utilize a data series which is incomplete as regards the parameter listings.
+
+1) Copy the executable "opt" in the work folder.
+
+2) Create a configuration file for Sim::OPT by modifying the "caravantrial.pl" file in the "examples" folder. It is sufficient to modify the values signalled by capital letters in the comments.
+
+3) Create a configuration file for Interlinear by modifying the first setting in the file "confinterlinear.pl" in the "examples" folder.
+
+4) Copy the .csv file in the work folder.
+
+5) Launch Sim::OPT in the shell: << ./opt >>
+
+6) When asked, specify the name (with relative path) of the Sim::OPT configuration file. For example:
+./caravantrial.pl
+
+7) Wait.
+
+
 =head2 EXPORT
 
 
